==> haskell-mmark-0.0.7.6-328-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-4B2m2ySzlh9IRIRj8hKfxm
key:                  mmark-0.0.7.6-4B2m2ySzlh9IRIRj8hKfxm
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  9494fc68bc1b0c3f2453033e89cd5c86
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-4B2m2ySzlh9IRIRj8hKfxm
depends:
    aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY base-4.17.2.1
    case-insensitive-1.2.1.0-1npN6GIJCWqp0RBxHaC5s containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    email-validate-2.3.2.21-Bluua0kM2JP5f7NLvKHqt0
    foldl-1.4.18-5gCbTwWMR3ZDhKEqrKbGmE
    hashable-1.4.6.0-AVmZwVVVmv9PclG6VBq0Z
    html-entity-map-0.1.0.0-3ZFklGGBklnK6VHPsjPxJB
    lucid-2.11.20250303-LNzIJOdmrWEL1ws0PzzGy3
    megaparsec-9.7.0-h6TIpk0ovfDneD2rtVfdC
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    modern-uri-0.3.6.1-GomVtpTyAE4CH0dk64LB8o mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    text-metrics-0.3.3-LnPXTxSJbV1E4o5NteHpra
    unordered-containers-0.2.20-9npXt9Xm1lq5WoODUfmSXc
    yaml-0.11.11.2-JCoArX6f32N83yvd9RQfTl

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmark-0.0.7.6-329-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-E1olIV1RV15LlrrNvIUnF4
key:                  mmark-0.0.7.6-E1olIV1RV15LlrrNvIUnF4
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  78e6b505013e80a5aac7bb2a8501c37b
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-E1olIV1RV15LlrrNvIUnF4
depends:
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb base-4.17.2.1
    case-insensitive-1.2.1.0-AMgBCf5fDYf4pbGdLaLtss containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    email-validate-2.3.2.21-HfZjtlFmfZk1JJUsBGrpod
    foldl-1.4.18-BukPFLGrzNcCMyhoGGcwhq
    hashable-1.4.6.0-HNsjIjcKtfz4EPsBV3Crzv
    html-entity-map-0.1.0.0-28fQRWYhVR3AOdNZcxaIGb
    lucid-2.11.20250303-2dh4xfQn3fKAVPtpSJVwcA
    megaparsec-9.7.0-ATzV0kIhS1c1WF6GxcAl4n
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    modern-uri-0.3.6.1-BlYvql7NIXH2eYVqhoLDgG mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    text-metrics-0.3.3-Eic0JH6CXesKn0BjlW1L8p
    unordered-containers-0.2.20-2t1vPVJZrFoJrApu3o7oBM
    yaml-0.11.11.2-Jvc0ApySr5o80fV68nxKXR

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
